@@ -1,4 +1,4 @@
-from arpakitlib.ar_sqlalchemy_util import get_string_info_from_declarative_base
+from arpakitlib.ar_sqlalchemy_util import get_string_info_from_declarative_base, get_string_info_from_declarative_base_2
 
 from project.sqlalchemy_db_.sqlalchemy_model.api_key import ApiKeyDBM
 from project.sqlalchemy_db_.sqlalchemy_model.common import SimpleDBM
@@ -9,4 +9,4 @@ from project.sqlalchemy_db_.sqlalchemy_model.user_token import UserTokenDBM
 from project.sqlalchemy_db_.sqlalchemy_model.verification_code import VerificationCodeDBM
 
 if __name__ == '__main__':
-    print(get_string_info_from_declarative_base(SimpleDBM))
+    print(get_string_info_from_declarative_base_2(SimpleDBM))
